@@ -8,6 +8,7 @@ import (
 	"github.com/davecgh/go-spew/spew"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
 
 	configv1 "github.com/openshift/api/config/v1"
@@ -25,6 +26,7 @@ import (
 	"github.com/openshift/cluster-config-operator/pkg/operator/kube_cloud_config"
 	"github.com/openshift/cluster-config-operator/pkg/operator/migration_aws_status"
 	"github.com/openshift/cluster-config-operator/pkg/operator/operatorclient"
+	"github.com/openshift/cluster-config-operator/pkg/operator/operatorloglevel"
 	"github.com/openshift/cluster-config-operator/pkg/operator/secureaccesstoken"
 )
 
@@ -38,6 +40,11 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 	if err != nil {
 		return err
 	}
+	dynamicClient, err := dynamic.NewForConfig(controllerContext.KubeConfig)
+	if err != nil {
+		return nil
+	}
+
 	configInformers := configv1informers.NewSharedInformerFactory(configClient, 10*time.Minute)
 	kubeInformersForNamespaces := v1helpers.NewKubeInformersForNamespaces(kubeClient,
 		"",
@@ -58,6 +65,8 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		controllerContext.EventRecorder,
 	)
 
+	logLevelNormalizer := operatorloglevel.NewLogLevelNormalizer(dynamicClient, operatorClient, controllerContext.EventRecorder)
+
 	kubeCloudConfigController := kube_cloud_config.NewController(
 		operatorClient,
 		configClient.ConfigV1(),
@@ -151,6 +160,7 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 	go operatorController.Run(ctx, 1)
 	go migrationAWSStatusController.Run(ctx, 1)
 	go secureAccessTokenAnnotationController.Run(ctx, 1)
+	go logLevelNormalizer.Run(ctx, 1)
 
 	<-ctx.Done()
 	return nil
